package 

import (
	"net/http"
	"fmt"
	"github.com/gorilla/mux"
)

type Route struct {
	Name        string
	Method      string
	Pattern     string
	HandlerFunc http.HandlerFunc
}

type Routes []Route

func NewRouter() *mux.Router {
	router := mux.NewRouter().StrictSlash(true)
	for _, route := range routes {
		var handler http.Handler
		handler = route.HandlerFunc
		handler = Logger(handler, route.Name)

		router.
			Methods(route.Method).
			Path(route.Pattern).
			Name(route.Name).
			Handler(handler)
	}

	return router
}

func Index(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "Hello World!")
}

var routes = Routes{
	Route{
		"Index",
		"GET",
		"/",
		Index,
	},

	Route{
		"BalanceGet",
		"GET",
		"/balance",
		BalanceGet,
	},

	Route{
		"BalanceLicGet",
		"GET",
		"/balance.lic",
		BalanceLicGet,
	},

	Route{
		"BillingDebtGet",
		"GET",
		"/billing/debt",
		BillingDebtGet,
	},

	Route{
		"BillingInfoGet",
		"GET",
		"/billing/info",
		BillingInfoGet,
	},

	Route{
		"BillingLimitsGet",
		"GET",
		"/billing/limits",
		BillingLimitsGet,
	},

	Route{
		"DnsProlongListGet",
		"GET",
		"/dns/prolong/list",
		DnsProlongListGet,
	},

	Route{
		"EmailAddGet",
		"GET",
		"/email/add",
		EmailAddGet,
	},

	Route{
		"EmailAliasDeleteGet",
		"GET",
		"/email/alias/delete",
		EmailAliasDeleteGet,
	},

	Route{
		"EmailAliasListGet",
		"GET",
		"/email/alias/list",
		EmailAliasListGet,
	},

	Route{
		"EmailDeleteGet",
		"GET",
		"/email/delete",
		EmailDeleteGet,
	},

	Route{
		"EmailListGet",
		"GET",
		"/email/list",
		EmailListGet,
	},

	Route{
		"UpdatesLastGet",
		"GET",
		"/updates/last",
		UpdatesLastGet,
	},

	Route{
		"UpdatesListGet",
		"GET",
		"/updates/list",
		UpdatesListGet,
	},

	Route{
		"WebsiteDeleteGet",
		"GET",
		"/website/delete",
		WebsiteDeleteGet,
	},

	Route{
		"WebsiteListGet",
		"GET",
		"/website/list",
		WebsiteListGet,
	},

	Route{
		"AuthLoginPost",
		"POST",
		"/auth/login",
		AuthLoginPost,
	},

	Route{
		"AuthStartGet",
		"GET",
		"/auth/start",
		AuthStartGet,
	},

	Route{
		"DnsAddGet",
		"GET",
		"/dns/add",
		DnsAddGet,
	},

	Route{
		"DnsBindGet",
		"GET",
		"/dns/bind",
		DnsBindGet,
	},

	Route{
		"DnsListGet",
		"GET",
		"/dns/list",
		DnsListGet,
	},

	Route{
		"DnsProlongListGet",
		"GET",
		"/dns/prolong/list",
		DnsProlongListGet,
	},

	Route{
		"DnsRawGet",
		"GET",
		"/dns/raw",
		DnsRawGet,
	},

	Route{
		"DnsRawManagedmxGet",
		"GET",
		"/dns/raw/managedmx",
		DnsRawManagedmxGet,
	},

	Route{
		"FtpListGet",
		"GET",
		"/ftp/list",
		FtpListGet,
	},

	Route{
		"IisListGet",
		"GET",
		"/iis/list",
		IisListGet,
	},

	Route{
		"MssqlListGet",
		"GET",
		"/mssql/list",
		MssqlListGet,
	},

	Route{
		"DatabaseListGet",
		"GET",
		"/database/list",
		DatabaseListGet,
	},

	Route{
		"VdsCreateGet",
		"GET",
		"/vds/create",
		VdsCreateGet,
	},

	Route{
		"VdsDeleteGet",
		"GET",
		"/vds/delete",
		VdsDeleteGet,
	},

	Route{
		"VdsIpAddGet",
		"GET",
		"/vds/ip/add",
		VdsIpAddGet,
	},

	Route{
		"VdsIpDeleteGet",
		"GET",
		"/vds/ip/delete",
		VdsIpDeleteGet,
	},

	Route{
		"VdsIpListGet",
		"GET",
		"/vds/ip/list",
		VdsIpListGet,
	},

	Route{
		"VdsListGet",
		"GET",
		"/vds/list",
		VdsListGet,
	},

	Route{
		"VdsRebootGet",
		"GET",
		"/vds/reboot",
		VdsRebootGet,
	},

	Route{
		"VdsTemplatesListGet",
		"GET",
		"/vds/templates-list",
		VdsTemplatesListGet,
	},

	Route{
		"VdsUpdateGet",
		"GET",
		"/vds/update",
		VdsUpdateGet,
	},

}